Index: /trunk/Ohana/src/opihi/dvo/dbCmdlineFields.c
===================================================================
--- /trunk/Ohana/src/opihi/dvo/dbCmdlineFields.c	(revision 19568)
+++ /trunk/Ohana/src/opihi/dvo/dbCmdlineFields.c	(revision 19569)
@@ -14,6 +14,6 @@
   dbInitField (&fields[0]);
 
-  // examine each argv[i] entry until we reach a where 
-  for (i = 1; (i < argc) && strcasecmp (argv[i], "where"); i++) {
+  // examine each argv[i] entry until we reach a 'where' or a 'matched' 
+  for (i = 1; (i < argc) && strcasecmp (argv[i], "where") && strcasecmp (argv[i], "matched"); i++) {
     // split the word by ","
     p = argv[i];
@@ -50,5 +50,6 @@
   }
 
-  // require 'where' before boolean math
+  // require 'where' or 'matched to' before boolean math
+  XXX push this to a test up one level
   if (i != argc) {
     if (strcasecmp(argv[i], "where")) {
